#
# spec file for package perl-Test-Compile
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Test-Compile
Name:           perl-Test-Compile
Version:        3.3.3
Release:        1.1
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Assert that your Perl files compile OK
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/E/EG/EGILES/%{cpan_name}-v%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Exporter) >= 5.68
BuildRequires:  perl(Module::Build) >= 0.38
BuildRequires:  perl(Test::More) >= 1.3
BuildRequires:  perl(parent) >= 0.225
Requires:       perl(Exporter) >= 5.68
Requires:       perl(parent) >= 0.225
%{perl_requires}

%description
'Test::Compile' lets you check the whether your perl modules and scripts
compile properly, results are reported in standard 'Test::Simple' fashion.

The basic usage - as shown above, will locate your perl files and test that
they all compile.

Module authors can (and probably should) include the following in a
_t/00-compile.t_ file and have 'Test::Compile' automatically find and check
all Perl files in a module distribution:

    #!perl
    use strict;
    use warnings;
    use Test::Compile qw();

    my $test = Test::Compile->new();
    $test->all_files_ok();
    $test->done_testing();

%prep
%autosetup  -n %{cpan_name}-v%{version}

%build
perl Build.PL --installdirs=vendor
./Build build --flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install --destdir=%{buildroot} --create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README
%license LICENSE

%changelog
* Mon May  6 2024 Tina Müller <timueller+perl@suse.de>
- updated to 3.3.3
  see /usr/share/doc/packages/perl-Test-Compile/Changes
  v3.3.3	  2024-05-06
  - Be more careful about windows filenames
  v3.3.2	  2024-05-03
  - Require a newer version of Test::More (fix CPAN testing failure?)
  - Don't add an unnecassary "./" to the start of filepaths (CPAN-RT 151090)
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Mon Jul 17 2023 Tina Müller <timueller+perl@suse.de>
- updated to 3.3.1
  see /usr/share/doc/packages/perl-Test-Compile/Changes
  v3.3.1	  2023-07-17
  - Fix 'silent, no taint' mode (which doesn't cause the compile to fail)
  v3.3.0	  2023-07-12
  - Tests should pass, even if Taint mode is not compiled into perl
  - Improve the documentation (@dirs was a terrible name)
  - Internal: improve error handling
  - Internal: remove redundant constants
  - Internal: simplify complex conditional (for better testing)
  - Internal: more tests for better coverage
* Thu Apr  6 2023 Tina Müller <timueller+perl@suse.de>
- updated to 3.2.2
  see /usr/share/doc/packages/perl-Test-Compile/Changes
  v3.2.2	  2023-04-06
  - Finally understand (and fix?) the test failures on windows
  v3.2.1	  2023-04-05
  - Try to resolve some issues highlighted by CpanTesters
* Mon Apr  3 2023 Tina Müller <timueller+perl@suse.de>
- updated to 3.2.0
  see /usr/share/doc/packages/perl-Test-Compile/Changes
  v3.2.0	  2023-04-03
  - Sort the output of all_pl_files() and all_pm_files()
  v3.1.1	  2023-03-28
  - Proof read and correct the POD
  - Be more consistent about where we search for files (by default)
  - Update copyright (2023)
* Fri Jun  3 2022 Tina Müller <timueller+perl@suse.de>
- updated to 3.1.0
  see /usr/share/doc/packages/perl-Test-Compile/Changes
  v3.1.0	  2022-06-02
  - (Tom Hukins) Treat files with .psgi extensions as perl
  - (Tom Hukins) Look for file in a case insensitive manner
  - Update the example code so it doesn't import anything
* Sun Aug 22 2021 Tina Müller <timueller+perl@suse.de>
- updated to 3.0.1
  see /usr/share/doc/packages/perl-Test-Compile/Changes
  v3.0.1	  2021-08-22
  - (waterkip) Really remove UNIVERSAL::require (CPAN-RT 138934)
  v3.0.0	  2021-08-21
  - Stop tring to detect the OS
  - Stop doing strange things for non posix systems (not backwards compatible)
  - Don't depend on UNIVERSAL::require
* Thu Jun 17 2021 Tina Müller <timueller+perl@suse.de>
- updated to 2.4.2
  see /usr/share/doc/packages/perl-Test-Compile/Changes
  v2.4.2	  2021-06-16
  - (dboehmer) make 'all_files_ok()' more consistent
  - (dboehmer) Fix typo
  - More documentation improvements
  - Yet more tests
  - Update copyright
* Tue Jul  7 2020 Tina Müller <timueller+perl@suse.de>
- updated to 2.4.1
  see /usr/share/doc/packages/perl-Test-Compile/Changes
  v2.4.1    2020-07-06
  - Fix if perl is installed in a dir with a space in it's path
  - Fix for Strwberry perl without Devel::CheckOS
* Sun Mar 29 2020 <timueller+perl@suse.de>
- updated to 2.4.0
  see /usr/share/doc/packages/perl-Test-Compile/Changes
  v2.4.0    2020-03-29
  - RT-132153: Be more verbose when in verbose mode
  - Update copyright
* Thu Oct 24 2019 <timueller+perl@suse.de>
- updated to 2.3.1
  see /usr/share/doc/packages/perl-Test-Compile/Changes
  v2.3.1    2019-10-23
  - RT-130694: all_pm_files_ok and all_pl_files_ok should return true/false
* Wed Oct  9 2019 <timueller+perl@suse.de>
- updated to 2.3.0
  see /usr/share/doc/packages/perl-Test-Compile/Changes
  v2.3.0    2019-10-09
  - Search for perl files in blib first (Alexandr Ciornii <alexchorny@gmail.com>)
  - Improve tests, remove redundant code,
  - Refactor POD, make the deprecation of the functional interface clearer
* Tue Jul 16 2019 Stephan Kulow <coolo@suse.com>
- updated to 2.2.2
  see /usr/share/doc/packages/perl-Test-Compile/Changes
  v2.2.2    2019-07-11
  - Fix cpan-test failures on mswin32
  v2.2.1    2019-07-09
  - Ooops, the module still depends on UNIVERSAL::require
  - Oh, and the subprocess function now requires perl 5.10.0
  v2.2.0    2019-07-08
  - RT-118530: Capture (and optionally suppress) all output from subcommands
  - RT-102817: Change the default value for 'verbose', from 1 to undef
  - RT-118419: pm and pl files are now both checked using 'perl -c'
  - Changes to POD: fixes to escaping, update for new functionality, simplify it
  - The module no longer depends on UNIVERSAL::require
  v2.1.2    2019-07-03
  - More corrections to the POD
  - More tests, try specifying specific files to all_pX_files()
  - Use the correct method in all_pl_files_ok() (Noel Maddy)
* Mon Jul  1 2019 Stephan Kulow <coolo@suse.com>
- updated to 2.1.1
  see /usr/share/doc/packages/perl-Test-Compile/Changes
* Fri Jun 28 2019 Stephan Kulow <coolo@suse.com>
- updated to 2.1.0
  see /usr/share/doc/packages/perl-Test-Compile/Changes
  v2.1.0    2019-XX-XX
  - Update copyright
  - Add all_pm_files_ok() and all_pl_files_ok() methods to the internal class
* Mon Jun 24 2019 Stephan Kulow <coolo@please-enter-an-email-address>
- updated to 2.0.1
  see /usr/share/doc/packages/perl-Test-Compile/Changes
* Wed Jun 19 2019 Stephan Kulow <coolo@please-enter-an-email-address>
- updated to 2.0.0
  see /usr/share/doc/packages/perl-Test-Compile/Changes
  v2.0_0    2019-06-18 (DEV RELEASE)
    Łukasz Hejnak <lehack@lehack.pl>
  - Replaced import() with Exporter usage.
  - Added all_files_ok to the procedural mode.
  - Added .git to list of directories ignored when looking for pm/pl files.
  - Added an else clause for pl_file_compiles so that it catches file not found errors.
    Evan Giles <egiles@cpan.org>
  - Remove 'exported_to' function
  - Remove cleanup steps from the Build.PL file
  - Bump version number for backwards incompatible changes (semver.org)
* Sat Sep 26 2015 coolo@suse.com
- updated to 1.3.0
  see /usr/share/doc/packages/perl-Test-Compile/Changes
* Tue Apr 14 2015 coolo@suse.com
- updated to 1.2.1
  see /usr/share/doc/packages/perl-Test-Compile/Changes
  v1.2.1    UNRELEASED              (Evan Giles <egiles@cpan.org>)
  - Fix (skip where appropriate) failing CPAN test
  - Avoid warnings for empty files in all_pl_files (Nigel Gregoire)
* Tue Dec  2 2014 coolo@suse.com
- updated to 1.2.0
  - Files without extension may not be perl (rt83917)
  - Small POD fix
  v1.1.0    2014-07-18              (Evan Giles <egiles@cpan.org>)
  - Allow use of Test::Compile in an object oriented manner
  - Promote the OO interface in the POD
  - Test::Compile::Internal is now verbose by default
  - Correct the dependancy information
  v1.0.1    2014-03-20              (Evan Giles <egiles@cpan.org>)
  - Fix stupid omission from the MANAIFEST (tests failed everywhere)
  v1.0.0    2014-03-19              (Evan Giles <egiles@cpan.org>)
  - Try to use Sematic Versioning - http://semver.org
  - Add diagnostics on compilation failure        (Micheal G. Schwern)
  - require, don't use                            (Micheal G. Schwern)
  - Test for truth, not an integer.               (Micheal G. Schwern)
  - Small POD fix                                 (Micheal G. Schwern)
  - OS X is not a crazy OS from a redirection POV (Micheal G. Schwern)
  0.24  2013 02 22                  (Evan Giles <egiles@cpan.org>)
  - Update POD to explain more problems with Test::Compile
  0.23  2013.01.23                  (Evan Giles <egiles@cpan.org>)
  - Update Copyright for 2013
  - CPAN-RT #82887, Sébastien Aperghis-Tramoni <sebastien@aperghis.net>
  - Correct handling of PERL5LIB
  - fix regexp to detect taint mode
  0.22  2012.10.31                  (Evan Giles <egiles@cpan.org>)
  - Set verbose on for the Test::Compile library (rt80187)
  0.21  2012.09.05                  (Evan Giles <egiles@cpan.org>)
  - Finally test that the verbose method actaully works.
  - Update the POD - mostly to simplify it.
  - Remove redundant code, yet more tests.
  - Test::Compile::Internal is no longer 'beta'.
  0.20  2012.08.08                  (Evan Giles <egiles@cpan.org>)
  - Tests should also work outside unix (rt78810)
  0.19  2012.08.03                  (Evan Giles <egiles@cpan.org>)
  - Introduce Test::Compile::Internal.pm
  - Utilise Test::Compile::Internal to get better test coverage
  0.18  2012.07.16                  (Evan Giles <egiles@cpan.org>)
  - Fix a warning that leaks out (rt78363)
  0.17  2012.02.25                   (Evan Giles <egiles@cpan.org>)
  - Another few tests for taint logic
  0.16_1 2012.02.23                   (Evan Giles <egiles@cpan.org>)
  - Reapply patches from Nicholas Bamber (rt55837 & rt72557)
  0.16   2012.02.21                   (Evan Giles <egiles@cpan.org>)
  - Skip tests if there are not files to test (rt69297)
  - Handle taint mode correctly (rt55837)
  - Add 'blib/lib' to the search path for scripts (rt72557)
  0.15  Fri 2012.02.03 20:33:55 NZST (Evan Giles <egiles@cpan.org>)
  - Fork, and run compile tests in the child process (rt73290 & rt73291)
  0.14  Tue 2012.01.10 20:03:24 NZST (Evan Giles <egiles@cpan.org>)
  - Convert to Module::Build
  - Improved test for pl_file_ok()
  - Better test coverage (which files do we process, failed to compile, etc)
  - Remove duplicate code
* Thu Apr 21 2011 coolo@opensuse.org
- initial package 0.13
  * created by cpanspec 1.78.04
